Compile-time struct generation backed by JSON Schema validation.
AutoStruct's primary API is AutoStruct.JsonSchema.
Use AutoStruct.JsonSchema in a module to generate a struct, validation
helpers, JSON conversion helpers, and encoder implementations from a JSON
Schema.